@@ -9,7 +9,7 @@ from torch_geometric.utils import degree
 import networkx as nx
 from itertools import product
 from math import cos, sin, pi, atan2
-from utils_base import angle_vector,getArotateM
+from .utils_base import angle_vector,getArotateM
 from rdkit.Chem.rdMolTransforms import SetDihedralDeg
 from rdkit.Chem.rdMolTransforms import GetDihedralDeg
 
