@@ -11,12 +11,12 @@ import json
 import copy
 import time
 
-from utils import get_allbonds_rotatiable
-from utils import choose_dihedral_pairs_atoms4
-from utils import get_one_bond_nei
-from utils import get_alphas_of_1conf
+from .utils import get_allbonds_rotatiable
+from .utils import choose_dihedral_pairs_atoms4
+from .utils import get_one_bond_nei
+from .utils import get_alphas_of_1conf
 
-from utils_base import pickle_
+from .utils_base import pickle_
 
 from rdkit.Chem.rdMolAlign import AlignMol
 import numpy as np
